* Output options: all can be turned on/off by adding or removing the NO;
* page number, date, centering, or page breaks, page length and width;
  OPTIONS NOnumber NOdate NOcenter FormDlim=' ' PageSize=MAX LineSize=140;
* Eliminate SAS default titles and names of tables in output (TRACE ON to show);
  TITLE; ODS TRACE OFF; ODS LISTING; ODS GRAPHICS;

***********************************************************************************;
*******             BEGIN MANIPULATION FOR HOFFMAN CHAPTER 2 DATA           *******;
*******                  CHANGE "filesave" to your directory                *******;
***********************************************************************************;

* Defining global variable for file location to be replaced in code below;
* \\Client\ precedes path in Virtual Desktop outside H drive;
  %LET filesave= C:\Dropbox\20FA_PSQF6242\PSQF6242_Example7;
* Location for SAS files for these models (uses macro variable filesave);
  LIBNAME filesave "&filesave.";

* Creating value value labels to use with categorical predictors;
PROC FORMAT; VALUE FDemGroup 1="1None" 2="2Future" 3="3Current"; 
             VALUE FSex 0="0Men" 1="1Women"; 
RUN;

* Import chapter 2 example data into work library as Example7;
DATA work.Example7; SET filesave.SAS_Chapter2;
* Center quantitative predictors;
  age85 = age - 85;
  grip9 = grip - 9;
* Create dummy-coded binary predictors for dementia groups;
  demNF=.; demNC=.; * Create two new empty variables;
  IF demgroup=1 THEN DO; demNF=0; demNC=0; END; * Replace each for none group;
  IF demgroup=2 THEN DO; demNF=1; demNC=0; END; * Replace each for future group;
  IF demgroup=3 THEN DO; demNF=0; demNC=1; END; * Replace each for current group;
* Label new variables  note semi-colon is only at the end of ALL labels;
  LABEL   
  age85=     "age85: Age in Years (0=85)"
  grip9=     "grip9: Grip Strength in Pounds (0=9)"
  sexMW=     "sexMW: Sex (0=M, 1=W)"
  demNF=     "demNF: Dementia Contrast for None=0 vs Future=1"
  demNC=     "demNC: Dementia Contrast for None=0 vs Current=1"
  cognition= "cognition: Cognition Outcome"
  demgroup=  "demgroup: Dementia Group 1N 2F 3C";
* Add value labels defined above to categorical predictors;
  FORMAT sexMW Fsex. demgroup Fdemgroup.; 
* Select cases complete on variables;
  IF NMISS(cognition,age,grip,sexmw,demgroup)>0 THEN DELETE;
RUN;


***********************************************************************************;
*******                   BEGIN GENERAL LINEAR MODELS                       *******;
***********************************************************************************;

* Demonstrating how to get predicted outcomes using "fake people";
* Each row is a fake person for which to create a predicted outcome;
DATA work.FakePeople; INPUT PersonID age grip sexMW demNF demNC demgroup; 
* Center predictors; age85=age-85; grip9=grip-9;
DATALINES; 
-99 85  9  0  0  0  1 
-99 85  9  0  1  0  2
-99 85  9  0  0  1  3
-99 85  9  1  0  0  1
-99 85  9  1  1  0  2
-99 85  9  1  0  1  3
; RUN;
* Merge with real data;
DATA work.Example7; SET work.FakePeople work.Example7; RUN;

* Open output directory to save results to;
ODS RTF FILE="&filesave.\Example7_SAS_Output.rtf" 
        STYLE=HTMLBlue STARTPAGE=NO BODYTITLE;

TITLE1 "SAS Eq 2.13: Adding Sex by Dementia Interaction";
TITLE2 "Manual Contrasts for Sex (0=Men) and Dementia (0=None)";
PROC GLM DATA=work.Example7 NAMELEN=100;
MODEL cognition = age85 grip9 age85*grip9 sexMW demNF demNC
                  sexMW*demNF sexMW*demNC / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
CONTRAST "Omnibus DF=2 Dementia*Sex Interaction Test"         sexMW*demNF 1, sexMW*demNC 1;
* In CONTRASTs below, linear combinations are created within a comma set (still 1 DF each);
CONTRAST "Omnibus DF=2 Dementia Simple Main Effect for Men"   demNF 1 sexMW*demNF 0, 
                                                              demNC 1 sexMW*demNC 0;
CONTRAST "Omnibus DF=2 Dementia Simple Main Effect for Women" demNF 1 sexMW*demNF 1, 
                                                              demNC 1 sexMW*demNC 1;
* Request columns of predicted outcome and SE for all cases;
OUTPUT OUT=work.PredOutcomes PREDICTED=Yhat STDP=SEyhat;
* Adjusted cell means (predicted outcomes for age=85 and grip=9);
ESTIMATE "Mean: Men   None"       intercept 1 sexMW 0 demNF  0 demNC 0 sexMW*demNF 0 sexMW*demNC 0;
ESTIMATE "Mean: Women None"       intercept 1 sexMW 1 demNF  0 demNC 0 sexMW*demNF 0 sexMW*demNC 0;
ESTIMATE "Mean: Men   Future"     intercept 1 sexMW 0 demNF  1 demNC 0 sexMW*demNF 0 sexMW*demNC 0;
ESTIMATE "Mean: Women Future"     intercept 1 sexMW 1 demNF  1 demNC 0 sexMW*demNF 1 sexMW*demNC 0;
ESTIMATE "Mean: Men   Current"    intercept 1 sexMW 0 demNF  0 demNC 1 sexMW*demNF 0 sexMW*demNC 0;
ESTIMATE "Mean: Women Current"    intercept 1 sexMW 1 demNF  0 demNC 1 sexMW*demNF 0 sexMW*demNC 1;
* DF=1 simple effects of sex per dementia group;
ESTIMATE "Sex Diff for None"                  sexMW 1 demNF  0 demNC 0 sexMW*demNF  0 sexMW*demNC 0;
ESTIMATE "Sex Diff for Future"                sexMW 1 demNF  0 demNC 0 sexMW*demNF  1 sexMW*demNC 0;
ESTIMATE "Sex Diff for Current"               sexMW 1 demNF  0 demNC 0 sexMW*demNF  0 sexMW*demNC 1;
* DF=1 simple effects dementia group per sex;
ESTIMATE "None-Future Diff for Men"           sexMW 0 demNF  1 demNC 0 sexMW*demNF  0 sexMW*demNC 0;
ESTIMATE "None-Future Diff for Women"         sexMW 0 demNF  1 demNC 0 sexMW*demNF  1 sexMW*demNC 0;
ESTIMATE "None-Current Diff for Men"          sexMW 0 demNF  0 demNC 1 sexMW*demNF  0 sexMW*demNC 0;
ESTIMATE "None-Current Diff for Women"        sexMW 0 demNF  0 demNC 1 sexMW*demNF  0 sexMW*demNC 1;
ESTIMATE "Future-Current Diff for Men"        sexMW 0 demNF -1 demNC 1 sexMW*demNF  0 sexMW*demNC 0;
ESTIMATE "Future-Current Diff for Women"      sexMW 0 demNF -1 demNC 1 sexMW*demNF -1 sexMW*demNC 1;
* DF=1 differences in simple effects = interactions;
ESTIMATE "A: Sex Effect differ between None and Future?"               sexMW*demNF  1 sexMW*demNC 0;
ESTIMATE "A: None-Future Effect differ by Sex?"                        sexMW*demNF  1 sexMW*demNC 0;
ESTIMATE "B: Sex Effect differ between None and Current?"              sexMW*demNF  0 sexMW*demNC 1;
ESTIMATE "B: None-Current Effect differ by Sex?"                       sexMW*demNF  0 sexMW*demNC 1;
ESTIMATE "C: Sex Effect differ between Future and Current?"            sexMW*demNF -1 sexMW*demNC 1;
ESTIMATE "C: Future-Current Effect differ by Sex?"                     sexMW*demNF -1 sexMW*demNC 1;
ODS OUTPUT Estimates=work.SavedEstimates; * Save to compute effect sizes;
RUN; QUIT; TITLE1; TITLE2;

* Calculate effect sizes from t-values;
DATA work.SavedEstimates; SET work.SavedEstimates; %LET df=541;
     CohenD=(2*tvalue)/SQRT(&df.);
     EffectR=tvalue/SQRT((tvalue*tvalue)+&df.); 
RUN;
* Print effect sizes;
TITLE "Effect Sizes";
PROC PRINT NOOBS DATA=work.SavedEstimates; 
     WHERE INDEX(Parameter,"Cognition")=0; * Remove intercepts;
     VAR Parameter Estimate StdErr probt CohenD EffectR; 
RUN; TITLE;

* Plot saved predicted values for fake people -- dementia as X;
PROC SGPLOT DATA=work.PredOutcomes;
     WHERE PersonID=-99; * Only for fake people;
     SERIES x=demgroup y=Yhat / GROUP=sexMW;
     XAXIS GRID LABEL="Dementia Group" VALUES=(1 TO 3 BY 1);
     YAXIS GRID LABEL="Predicted Cognition" VALUES=(0 TO 35 BY 5);
	*FORMAT demgroup Fdemgroup. sexMW Fsex.; * Add value labels;
RUN; QUIT;

* Plot saved predicted values for fake people -- sex as X;
PROC SGPLOT DATA=work.PredOutcomes;
     WHERE PersonID=-99; * Only for fake people;
     SERIES x=sexMW y=Yhat / GROUP=demgroup;
     XAXIS GRID LABEL="Sex" VALUES=(0 TO 1 BY 1);
     YAXIS GRID LABEL="Predicted Cognition" VALUES=(0 TO 35 BY 5);
	*FORMAT demgroup Fdemgroup. sexMW Fsex.; * Add value labels;
RUN; QUIT;


TITLE1 "SAS Eq 2.13: Adding Sex by Dementia Interaction";
TITLE2 "Manual Contrast for Sex (0=Men) and Program-Categorical Dementia (Ref=Current)";
PROC GLM DATA=work.Example7 NAMELEN=100;
CLASS demgroup;   * CLASS: demgroup is categorical (program makes dummy codes);
MODEL cognition = age85 grip9 age85*grip9 sexMW demgroup
                  sexMW*demgroup / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
* First two CONTRASTs below now given by default with use of CLASS;
CONTRAST "Omnibus DF=2 Dementia*Sex Interaction Test"         sexMW*demgroup -1 1 0, sexMW*demgroup -1 0 1;
* In CONTRASTs below, linear combinations are created within a comma set (still 1 DF each);
CONTRAST "Omnibus DF=2 Dementia Simple Main Effect for Men"   demgroup -1 1 0 sexMW*demgroup  0 0 0, 
                                                              demgroup -1 0 1 sexMW*demgroup  0 0 0;
CONTRAST "Omnibus DF=2 Dementia Simple Main Effect for Women" demgroup -1 1 0 sexMW*demgroup -1 1 0, 
                                                              demgroup -1 0 1 sexMW*demgroup -1 0 1;
* Request columns of predicted outcome and SE for all cases;
OUTPUT OUT=work.PredOutcomes PREDICTED=Yhat STDP=SEyhat;
* Adjusted cell means (at age=85 and grip=9)and simple effects of dementia group diffs per sex;
LSMEANS demgroup / STDERR TDIFF PDIFF ADJUST=T DIFF=ALL AT(age85 grip9 sexMW) = (0 0 0); * For men;
LSMEANS demgroup / STDERR TDIFF PDIFF ADJUST=T DIFF=ALL AT(age85 grip9 sexMW) = (0 0 1); * For women;
* DF=1 simple effects of sex per dementia group (not redundant with LSMEANS);
ESTIMATE "Sex Diff for None"             demgroup  0  0  0  sexMW 1  sexMW*demgroup  1  0  0;
ESTIMATE "Sex Diff for Future"           demgroup  0  0  0  sexMW 1  sexMW*demgroup  0  1  0;
ESTIMATE "Sex Diff for Current"          demgroup  0  0  0  sexMW 1  sexMW*demgroup  0  0  1;
* DF=1 simple effects of dementia group per sex (redundant with LSMEANS);
ESTIMATE "None-Future Diff for Men"      demgroup -1  1  0  sexMW 0  sexMW*demgroup  0  0  0;
ESTIMATE "None-Future Diff for Women"    demgroup -1  1  0  sexMW 0  sexMW*demgroup -1  1  0;
ESTIMATE "None-Current Diff for Men"     demgroup -1  0  1  sexMW 0  sexMW*demgroup  0  0  0;
ESTIMATE "None-Current Diff for Women"   demgroup -1  0  1  sexMW 0  sexMW*demgroup -1  0  1;
ESTIMATE "Future-Current Diff for Men"   demgroup  0 -1  1  sexMW 0  sexMW*demgroup  0  0  0;
ESTIMATE "Future-Current Diff for Women" demgroup  0 -1  1  sexMW 0  sexMW*demgroup  0 -1  1;
* DF=1 differences in simple effects = interactions (not redundant with LSMEANS);
ESTIMATE "A: Sex Effect differ between None and Future?"             sexMW*demgroup -1  1  0;
ESTIMATE "A: None-Future Effect differ by Sex?"     		         sexMW*demgroup -1  1  0;
ESTIMATE "B: Sex Effect differ between None and Current?"            sexMW*demgroup -1  0  1;
ESTIMATE "B: None-Current Effect differ by Sex?"    		         sexMW*demgroup -1  0  1;
ESTIMATE "C: Sex Effect differ between Future and Current?"          sexMW*demgroup  0 -1  1;
ESTIMATE "C: Future-Current Effect differ by Sex?"  		         sexMW*demgroup  0 -1  1;
RUN; QUIT; TITLE1; TITLE2;


TITLE1 "SAS Eq 2.13: Adding Sex by Dementia Interaction";
TITLE2 "Program-Categorical Sex (Ref=Women) and Program-Categorical Dementia (Ref=Current)";
PROC GLM DATA=work.Example7 NAMELEN=100;
CLASS sexMW demgroup; * CLASS: sexMW and demgroup are categorical;
MODEL cognition = age85 grip9 age85*grip9 sexMW demgroup
                  sexMW*demgroup / ALPHA=.05 CLPARM SOLUTION SS3 EFFECTSIZE;
* CONTRAST for interaction given by default with use of CLASS;
CONTRAST "Omnibus DF=2 Dementia*Sex Interaction Test" sexMW*demgroup -1 1 0 1 -1 0, 
                                                      sexMW*demgroup -1 0 1 1 0 -1;
* Request columns of predicted outcome and SE for all cases;
OUTPUT OUT=work.PredOutcomes PREDICTED=Yhat STDP=SEyhat;
* Marginal sex means and tests diffs averaged over demgroup;
LSMEANS sexMW    / STDERR TDIFF PDIFF ADJUST=T DIFF=ALL AT(age85 grip9) = (0 0); 
* Marginal demgroup means and tests of diffs averaged over sex;
LSMEANS demgroup / STDERR TDIFF PDIFF ADJUST=T DIFF=ALL AT(age85 grip9) = (0 0);
* Traditional ANOVA output ends here;
*  Adjusted cell means (at age=85 and grip=9) and simple effect tests (SLICE means per);
LSMEANS sexMW*demgroup / STDERR TDIFF PDIFF ADJUST=T SLICE=demgroup SLICE=sexMW 
                         DIFF=ALL AT(age85 grip9) = (0 0); 
* Order by CLASS statement: MN MF MC WN WF WC -- check order with / E;
* DF=1 simple effects of sex per dementia group (redundant with LSMEANS);
ESTIMATE 'Sex Diff for None'          demgroup  0  0  0 sexMW -1 1 sexMW*demgroup -1  0  0  1  0  0 / E;
ESTIMATE 'Sex Diff for Fut'           demgroup  0  0  0 sexMW -1 1 sexMW*demgroup  0 -1  0  0  1  0;
ESTIMATE 'Sex Diff for Cur'           demgroup  0  0  0 sexMW -1 1 sexMW*demgroup  0  0 -1  0  0  1;
* DF=1 simple effects of dementia group per sex (redundant with LSMEANS);
ESTIMATE 'None-Fut Diff for Men'      demgroup -1  1  0 sexMW  0 0 sexMW*demgroup -1  1  0  0  0  0;
ESTIMATE 'None-Fut Diff for Women'    demgroup -1  1  0 sexMW  0 0 sexMW*demgroup  0  0  0 -1  1  0;
ESTIMATE 'None-Cur Diff for Men'      demgroup -1  0  1 sexMW  0 0 sexMW*demgroup -1  0  1  0  0  0;
ESTIMATE 'None-Cur Diff for Women'    demgroup -1  0  1 sexMW  0 0 sexMW*demgroup  0  0  0 -1  0  1;
ESTIMATE 'Fut-Cur Diff for Men'       demgroup  0 -1  1 sexMW  0 0 sexMW*demgroup  0 -1  1  0  0  0;
ESTIMATE 'Fut-Cur Diff for Women'     demgroup  0 -1  1 sexMW  0 0 sexMW*demgroup  0  0  0  0 -1  1;
* DF=1 differences in simple effects = interactions (not redundant with LSMEANS);
ESTIMATE "A: Sex Effect differ between None and Future?"           sexMW*demgroup -1  1  0  1 -1  0;
ESTIMATE "A: None-Future Effect differ by Sex?"                    sexMW*demgroup -1  1  0  1 -1  0;
ESTIMATE "B: Sex Effect differ between None and Current?"          sexMW*demgroup -1  0  1  1  0 -1;
ESTIMATE "B: None-Cur Effect differ by Sex?"                       sexMW*demgroup -1  0  1  1  0 -1;
ESTIMATE "C: Sex Effect differ between Future and Current?"        sexMW*demgroup  0 -1  1  0  1 -1;
ESTIMATE "C: Future-Current Effect differ by Sex?"                 sexMW*demgroup  0 -1  1  0  1 -1;
RUN; QUIT; TITLE1; TITLE2;


* Close output;
ODS RTF CLOSE;

