// Prevent "more" messages from appearing
   set more off
// Control line length
   set linesize 150

////////////////////////////////////////////////////////////////////////////////
////////             BEGIN MANIPULATION FOR HOFFMAN CHAPTER 2 DATA        ///////
////////               CHANGE "filesave" to your directory                ///////
////////////////////////////////////////////////////////////////////////////////

// Defining global variable for file location to be replaced in code below
// \\Client\ precedes path in Virtual Desktop outside H drive
   global filesave "C:\Dropbox\20FA_PSQF6242\PSQF6242_Example7"

// Import chapter 2 data into temporary file and center predictors
   use "$filesave\STATA_Chapter2.dta", clear // Has converted all variables to lower-case

// Save results to separate file
   log using $filesave\Example7_STATA_Output.log, replace

// Center quantitative predictors
   gen age85 = age - 85
   gen grip9 = grip - 9
// Create dummy-coded binary predictors for dementia groups
   gen demnf=.
   gen demnc=.
// Demgroup = none   
   replace demnf=0 if demgroup==1
   replace demnc=0 if demgroup==1
// Demgroup = future 
   replace demnf=1 if demgroup==2
   replace demnc=0 if demgroup==2
// Demgroup = current
   replace demnf=0 if demgroup==3
   replace demnc=1 if demgroup==3
// Add value labels 
   label define fdemgroup 1 "1None" 2 "2Future" 3 "3Current"
   label values demgroup fdemgroup
   label define fsex 0 "0Men" 1 "1Women" 
   label values sexmw fsex
// Label all variables
   label variable age85    "age85: Age in Years (0=85)"
   label variable grip9    "grip9: Grip Strength in Pounds (0=9)"
   label variable sexmw     "sexmw: Sex (0=Men, 1=Women)"
   label variable demnf     "demnf: Dementia Contrast for None=0 vs Future=1"
   label variable demnc     "demnc: Dementia Contrast for None=0 vs Current=1"
   label variable cognition "cognition: Cognition Outcome"
   label variable demgroup  "demgroup: Dementia Group 1N 2F 3C"

// Select cases complete on variables
   egen nmiss=rowmiss(cognition age grip sexmw demgroup)
   drop if nmiss>0

    
////////////////////////////////////////////////////////////////////////////////
////////                  BEGIN GENERAL LINEAR MODELS                     //////
////////////////////////////////////////////////////////////////////////////////

display "STATA Eq 2.13: Adding Sex by Dementia Interaction"
display "Manual Contrasts for Sex (0=Men) and Dementia (0=None)"
regress cognition c.age85 c.grip9 c.age85#c.grip9 c.sexmw c.demnf c.demnc ///
                  c.sexmw#c.demnf c.sexmw#c.demnc, level(95)
// Omnibus DF=2 Dementia*Sex Interaction Test              
test (c.sexmw#c.demnf=0) (c.sexmw#c.demnc=0) 
// In TESTs below, linear combinations are created within parentheses (still 1 DF each)
// Omnibus DF=2 Dementia Simple Main Effect for Men
test (c.demnf*1 + c.sexmw#c.demnf*0 =0)(c.demnc*1 + c.sexmw#c.demnc*0=0)                    
// Omnibus DF=2 Dementia Simple Main Effect for Men
test (c.demnf*1 + c.sexmw#c.demnf*1 =0)(c.demnc*1 + c.sexmw#c.demnc*1=0)  
// Adjusted cell means (predicted outcomes for age=85 and grip=9)
margins, at(c.age85=0 c.grip9=0 c.sexmw=(0(1)1) c.demnf=0 c.demnc=0) // Means for None
margins, at(c.age85=0 c.grip9=0 c.sexmw=(0(1)1) c.demnf=1 c.demnc=0) // Means for Future
margins, at(c.age85=0 c.grip9=0 c.sexmw=(0(1)1) c.demnf=0 c.demnc=1) // Means for Current
// DF=1 simple effects of sex per dementia group
lincom c.sexmw*1 + c.sexmw#c.demnf*0 + c.sexmw#demnc*0  // Sex Diff for No Dementia
lincom c.sexmw*1 + c.sexmw#c.demnf*1 + c.sexmw#demnc*0  // Sex Diff for Future Dementia
lincom c.sexmw*1 + c.sexmw#c.demnf*0 + c.sexmw#demnc*1  // Sex Diff for Current Dementia
// DF=1 simple effects of dementia group per sex
lincom c.demnf*1  + c.demnc*0 + c.sexmw#c.demnf*0  + c.sexmw#c.demnc*0 // None-Future Diff for Men
lincom c.demnf*1  + c.demnc*0 + c.sexmw#c.demnf*1  + c.sexmw#c.demnc*0 // None-Future Diff for Women
lincom c.demnf*0  + c.demnc*1 + c.sexmw#c.demnf*0  + c.sexmw#c.demnc*0 // None-Current Diff for Men
lincom c.demnf*0  + c.demnc*1 + c.sexmw#c.demnf*0  + c.sexmw#c.demnc*1 // None-Current Diff for Women 
lincom c.demnf*-1 + c.demnc*1 + c.sexmw#c.demnf*0  + c.sexmw#c.demnc*0 // Future-Current Diff for Men
lincom c.demnf*-1 + c.demnc*1 + c.sexmw#c.demnf*-1 + c.sexmw#c.demnc*1 // Future-Current Diff for Women
// DF=1 differences in simple effects = interactions
lincom c.sexmw#c.demnf*1  + c.sexmw#c.demnc*0  // A: Sex Effect differ between None and Future?
lincom c.sexmw#c.demnf*1  + c.sexmw#c.demnc*0  // A: None-Future Effect differ by Sex?
lincom c.sexmw#c.demnf*0  + c.sexmw#c.demnc*1  // B: Sex Effect differ between None and Current?
lincom c.sexmw#c.demnf*0  + c.sexmw#c.demnc*1  // B: None-Current Effect differ by Sex?
lincom c.sexmw#c.demnf*-1 + c.sexmw#c.demnc*1  // C: Sex Effect differ between Future and Current?
lincom c.sexmw#c.demnf*-1 + c.sexmw#c.demnc*1  // C: Future-Current Effect differ by Sex?


display "STATA Eq 2.13: Adding Sex by Dementia Interaction"
display "Manual Contrast for Sex (0=Men) and Program-Categorical Dementia (Ref=Current)"
regress cognition c.age85 c.grip9 c.age85#c.grip9 c.sexmw ib(last).demgroup  ///
                  c.sexmw#ib(last).demgroup, level(95)
// Omnibus DF=2 Dementia*Sex Interaction Test
contrast c.sexmw#i.demgroup 
// In TESTs below, linear combinations are created within parentheses (still 1 DF each)
// Omnibus DF=2 Dementia Simple Main Effect for Men
test (i1.demgroup*1 + c.sexmw#i1.demgroup*0 =0) (i2.demgroup*1 + c.sexmw#i2.demgroup*0 =0) 
// Omnibus DF=2 Dementia Simple Main Effect for Women
test (i1.demgroup*1 + c.sexmw#i1.demgroup*1 =0) (i2.demgroup*1 + c.sexmw#i2.demgroup*1 =0)      
// Adjusted cell means (predicted outcomes for age=85 and grip=9)      
margins  i.demgroup, at(c.sexmw=(0(1)1) c.age85=0 c.grip9=0) vsquish    
marginsplot, xdimension(demgroup) // Plot pred outcomes by dementia group  
marginsplot, xdimension(sexmw)    // Plot pred outcomes by sex      
// Dem pairwise (means, then diffs) for Men        
margins  i.demgroup, at(c.sexmw=0 c.age85=0 c.grip9=0) vsquish      
margins  i.demgroup, at(c.sexmw=0 c.age85=0 c.grip9=0) vsquish pwcompare(pveffects) 
// Dem pairwise (means, then diffs) for Women         
margins  i.demgroup, at(c.sexmw=1 c.age85=0 c.grip9=0) vsquish 
margins  i.demgroup, at(c.sexmw=1 c.age85=0 c.grip9=0) vsquish  pwcompare(pveffects)
// DF=1 simple effects of sex per dementia group (not redundant with margins)
lincom c.sexmw*1 + c.sexmw#i1.demgroup*1  // Sex diff for None
lincom c.sexmw*1 + c.sexmw#i2.demgroup*1  // Sex diff for Future
lincom c.sexmw*1 + c.sexmw#i3.demgroup*1  // Sex diff for Current
// DF=1 dementia simple group diffs (redundant with margins)
// None-Future Diff  for Men
lincom i1.demgroup*-1 +i2.demgroup*1 + c.sexmw#i1.demgroup*0  + c.sexmw#i2.demgroup*0 
// None-Future Diff  for Women
lincom i1.demgroup*-1 +i2.demgroup*1 + c.sexmw#i1.demgroup*-1 + c.sexmw#i2.demgroup*1 
// None-Current Diff  for Men
lincom i1.demgroup*-1 +i3.demgroup*1 + c.sexmw#i1.demgroup*0  + c.sexmw#i3.demgroup*0 
// None-Current Diff  for Women 
lincom i1.demgroup*-1 +i3.demgroup*1 + c.sexmw#i1.demgroup*-1 + c.sexmw#i3.demgroup*1 
// Fut-Cur Diff for Men
lincom i2.demgroup*-1 +i3.demgroup*1 + c.sexmw#i2.demgroup*0  + c.sexmw#i3.demgroup*0
// Fut-Cur Diff for Women
lincom i2.demgroup*-1 +i3.demgroup*1 + c.sexmw#i2.demgroup*-1 + c.sexmw#i3.demgroup*1
// DF=1 differences in simple effects = interactions (not redundant with margins)
lincom c.sexmw#i1.demgroup*-1 + c.sexmw#i2.demgroup*1 // A: Sex Effect differ btw None and Future?
lincom c.sexmw#i1.demgroup*-1 + c.sexmw#i2.demgroup*1 // A: None-Future Effect differ by Sex?
lincom c.sexmw#i1.demgroup*-1 + c.sexmw#i3.demgroup*1 // B: Sex Effect differ btw None and Current?
lincom c.sexmw#i1.demgroup*-1 + c.sexmw#i3.demgroup*1 // B: None-Current Effect differ by Sex?
lincom c.sexmw#i2.demgroup*-1 + c.sexmw#i3.demgroup*1 // C: Sex Effect differ btw Future and Current?
lincom c.sexmw#i2.demgroup*-1 + c.sexmw#i3.demgroup*1 // C: Future-Current Effect differ by Sex?


display "STATA Eq 2.13: Adding Sex by Dementia Interaction"
display "Program-Categorical Sex (Ref=Women) and Program-Categorical Dementia (Ref=Current)" 
regress cognition c.age85 c.grip9 c.age85#c.grip9 ib(last).sexmw ib(last).demgroup ///
                   ib(last).sexmw#ib(last).demgroup, level(95)
contrast i.sexmw#i.demgroup // Omnibus Df=2 Dementia*Sex Interaction Test (not given by default)
contrast i.sexmw            // Omnibus DF=1 Marginal Sex Main Effect (not given by default)
contrast i.demgroup         // Omnibus DF=2 Marginal Dementia Main Effect (not given by default)
// Marginal means (then diffs) for Sex
margins  i.sexmw, asbalanced at(c.age85=0 c.grip9=0) vsquish                        
margins  i.sexmw, asbalanced at(c.age85=0 c.grip9=0) vsquish pwcompare(pveffects)  
// Marginal means (then diffs) for Dementia
margins  i.demgroup, asbalanced at(c.age85=0 c.grip9=0) vsquish                       
margins  i.demgroup, asbalanced at(c.age85=0 c.grip9=0) vsquish pwcompare(pveffects)
// Traditional ANOVA output ends here
// Adjusted cell means (at age=85 and grip=9) then diffs
margins  i.sexmw#i.demgroup, at(c.age85=0 c.grip9=0) vsquish  
margins  i.sexmw#i.demgroup, at(c.age85=0 c.grip9=0) vsquish pwcompare(pveffects)
// DF=1 simple effect of sex per demgroup (not redundant with margins)
margins  i.sexmw@i.demgroup, at(c.age85=0 c.grip9=0) 
// DF=2 simple effect of demgroup per sex (not redundant with margins)
margins  i.demgroup@i.sexmw, at(c.age85=0 c.grip9=0) 
// DF=1 differences in simple effects = interactions (not redundant with margins)
contrast {i.sexmw#i.demgroup  1 -1  0 -1  1  0} // A: Sex Effect differ between None and Future?
contrast {i.sexmw#i.demgroup  1 -1  0 -1  1  0} // A: None-Future Effect differ by Sex?
contrast {i.sexmw#i.demgroup  1  0 -1 -1  0  1} // B: Sex Effect differ between None and Current?
contrast {i.sexmw#i.demgroup  1  0 -1 -1  0  1} // B: None-Current Effect differ by Sex?
contrast {i.sexmw#i.demgroup  0  1 -1  0 -1  1} // C: Sex Effect differ between Future and Current?
contrast {i.sexmw#i.demgroup  0  1 -1  0 -1  1} // C: Future-Current Effect differ by Sex?


// Close log
log close

